@@ -1,5 +1,5 @@
 /*
- *  R : A Computer Langage for Statistical Data Analysis
+ *  R : A Computer Language for Statistical Data Analysis
  *  Copyright (C) 1995, 1996  Robert Gentleman and Ross Ihaka
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -21,24 +21,44 @@
 #define ARITH_H_
 
 #include "Platform.h"
-#ifdef Macintosh
-#include <fp.h>
+
+/* Maybe get  finite(.) : */
+#ifdef HAVE_IEEE754_H
+#include <ieee754.h> /* newer Linuxen */
 #else
-#include <math.h>
-#ifndef HAVE_FINITE
-#ifndef finite /* Do not declare if macro! */
-int finite(double);
+#ifdef HAVE_IEEEFP_H
+#include <ieeefp.h> /* others [Solaris 2.5.x], .. */
 #endif
 #endif
+
+#ifdef Macintosh
+# include <fp.h>
+#else
+# include <math.h>
+# ifndef HAVE_FINITE
+#  ifndef finite /* Do not declare if macro! */
+#   ifdef isfinite/* HPUX math.h */
+#     define finite(x)	 isfinite(x)
+#   else
+      int finite(double);
+#   endif
+#  endif
+# endif
 #endif
 
 extern double	R_tmp;			/* Used in NaN/Inf checks */
 extern double	R_NaN;			/* IEEE NaN or -DBL_MAX */
 extern double	R_PosInf;		/* IEEE Inf or DBL_MAX */
 extern double	R_NegInf;		/* IEEE -Inf or -DBL_MAX */
-extern int   	R_NaInt;		/* NA_INTEGER etc */
+extern int	R_NaInt;		/* NA_INTEGER etc */
 extern double	R_NaReal;		/* NA_REAL */
 
+#define NA_LOGICAL	R_NaInt
+#define NA_INTEGER	R_NaInt
+#define NA_FACTOR	R_NaInt
+#define NA_REAL		R_NaReal
+#define NA_STRING	R_NaString
+
 #ifdef Win32
 extern int isnan(double);
 extern int finite(double);
@@ -46,17 +66,31 @@ extern int finite(double);
 
 #ifdef IEEE_754
 
+int R_IsNA(double);/* True for Real NA only */
+int R_IsNaN(double);/* True for special NaN,  *not* for NA */
+
 #define MATH_CHECK(call)	(call)
 #define FINITE(x)		finite(x)
-#define ISNAN(x)		((x)!=(x))/* True, *both* for NA & NaN */
-#define ISNA(x)			R_IsNA(x) /* --> ../main/arithmetic.c */
+#define ISNAN(x)		((x)!=(x))/* -> True, *both* for NA | NaN */
+#define ISNA(x)			R_IsNA(x) /* from ../main/arithmetic.c */
 
 #else
 
 #define MATH_CHECK(call)	(errno=0,R_tmp=call,(errno==0)?R_tmp:R_NaN)
-#define FINITE(x)		((x)!=R_NaReal)
-#define ISNAN(x)		((x)!=R_NaReal)/* ?? rather not -- FIXME!! */
-#define ISNA(x)			((x)!=R_NaReal)/* ?? rather not -- FIXME!! */
+
+#ifndef HAVE_FINITE
+#define FINITE(x)               ((x)!= R_NaReal)
+#else
+#define FINITE(x)		finite(x)
+#endif
+
+#ifndef HAVE_ISNAN
+#define ISNAN(x)                ((x)==R_NaReal)
+#else
+#define ISNAN(x)                (isnan(x) || (x)==R_NaReal)
+#endif
+
+#define ISNA(x)                 ((x)==R_NaReal)
 /* never used. in HP-UX' c89 "NAN" is for a double const. :
  * #define NAN(x)			ISNAN(x)
  */
