@@ -1,9 +1,11 @@
 contour <-
     function (x = seq(0, 1, len = nrow(z)), y = seq(0, 1, len = ncol(z)),
-	      z, nlevels = 10, levels = pretty(range(z, finite = TRUE),
-			       nlevels), labcex = 0, xlim = range(x, finite = TRUE),
-	      ylim = range(y, finite = TRUE), col = par("fg"), lty = par("lty"),
-	      add = FALSE, ...)
+	      z, nlevels = 10,
+              levels = pretty(range(z[is.finite(z)]), nlevels),
+              labcex = 0,
+              xlim = range(x[is.finite(x)]), 
+	      ylim = range(y[is.finite(y)]),
+              col = par("fg"), lty = par("lty"), add = FALSE, ...)
 {
     ## labcex is disregarded since we do NOT yet put  ANY labels...
     if (missing(z)) {
