@@ -81,14 +81,26 @@ void PrintDefaults(SEXP rho)
 SEXP do_sink(SEXP call, SEXP op, SEXP args, SEXP rho)
 {
     FILE *fp;
-    if(isNull(CAR(args))) {
+    SEXP file;
+    int  append;
+
+    file = CAR(args);
+    append = asLogical(CADR(args));
+    if (append == NA_LOGICAL)
+        errorcall(call, "invalid append specification\n");
+    
+    if(isNull(file)) {
 	if(R_Sinkfile) fclose(R_Sinkfile);
 	R_Sinkfile = NULL;
 	R_Outputfile = R_Consolefile;
     } else {
-	if(TYPEOF(CAR(args)) != STRSXP || LENGTH(CAR(args)) != 1)
+	if (!isString(file) || length(file) != 1)
 	    errorcall(call, "invalid file name\n");
-	if( !(fp=R_fopen(CHAR(STRING(CAR(args))[0]), "w")))
+	if (append)
+	    fp = R_fopen(R_ExpandFileName(CHAR(STRING(file)[0])), "a");
+	else
+	    fp = R_fopen(R_ExpandFileName(CHAR(STRING(file)[0])), "w");
+	if (!fp)
 	    errorcall(call, "unable to open file\n");
 	R_Sinkfile = fp;
 	R_Outputfile = fp;
@@ -215,7 +227,7 @@ SEXP do_printdefault(SEXP call, SEXP op, SEXP args, SEXP rho){
 static void PrintGenericVector(SEXP s, SEXP env)
 {
     int i, taglen, ns;
-    SEXP dims, t, names, newcall;
+    SEXP dims, t, names, newcall, tmp;
     char *pbuf, *ptag;
 
     ns = length(s);
@@ -223,26 +235,26 @@ static void PrintGenericVector(SEXP s, SEXP env)
 	PROTECT(dims);
 	PROTECT(t = allocArray(STRSXP, dims));
 	for (i = 0 ; i < ns ; i++) {
-	    switch(TYPEOF(VECTOR(s)[i])) {
+	    switch(TYPEOF(PROTECT(tmp = VECTOR(s)[i]))) {
 	    case NILSXP:
 		pbuf = Rsprintf("NULL");
 		break;
 	    case LGLSXP:
-		pbuf = Rsprintf("Logical,%d", LENGTH(CAR(s)));
+		pbuf = Rsprintf("Logical,%d", LENGTH(tmp));
 		break;
 	    case INTSXP:
 	    case REALSXP:
-		pbuf = Rsprintf("Numeric,%d", LENGTH(CAR(s)));
+		pbuf = Rsprintf("Numeric,%d", LENGTH(tmp));
 		break;
 	    case CPLXSXP:
-		pbuf = Rsprintf("Complex,%d", LENGTH(CAR(s)));
+		pbuf = Rsprintf("Complex,%d", LENGTH(tmp));
 		break;
 	    case STRSXP:
-		pbuf = Rsprintf("Character,%d", LENGTH(CAR(s)));
+		pbuf = Rsprintf("Character,%d", LENGTH(tmp));
 		break;
 	    case LISTSXP:
 	    case VECSXP:
-		pbuf = Rsprintf("List,%d", length(CAR(s)));
+		pbuf = Rsprintf("List,%d", length(tmp));
 		break;
 	    case LANGSXP:
 		pbuf = Rsprintf("Expression");
@@ -251,6 +263,7 @@ static void PrintGenericVector(SEXP s, SEXP env)
 		pbuf = Rsprintf("?");
 		break;
 	    }
+	    UNPROTECT(1); /* tmp */
 	    STRING(t)[i] = mkChar(pbuf);
 	}
 	if (LENGTH(dims) == 2) {
