@@ -616,9 +616,9 @@ SEXP do_subset2(SEXP call, SEXP op, SEXP args, SEXP rho)
 	    PROTECT(index = allocVector(INTSXP, nsubs));
 	    dimnames = getAttrib(x, R_DimNamesSymbol);
 	    for (i = 0; i < nsubs; i++) {
-		INTEGER(index)[i] = get1index(CAR(subs), CAR(dimnames), 1);
+		INTEGER(index)[i] = get1index(CAR(subs),
+		        VECTOR(dimnames)[i], 1);
 		subs = CDR(subs);
-		dimnames = CDR(dimnames);
 		if (INTEGER(index)[i] < 0 ||
 		    INTEGER(index)[i] >= INTEGER(dims)[i])
 		    errorcall(call, "subscript out of bounds\n");
